summaryrefslogtreecommitdiff
path: root/include/linux
diff options
context:
space:
mode:
authorJinyoung Park <jinyoungp@nvidia.com>2013-06-20 17:55:41 +0900
committerGabby Lee <galee@nvidia.com>2013-06-25 23:31:24 -0700
commitf8664172759b7846bd046779c1ca4be672a6fee8 (patch)
treee0292f76b0663a76d5d2c3b31e802b915f4827c0 /include/linux
parent49178ad8b6616fd582ceec8ebd0fb8030124f90b (diff)
staging: iio: Support second value read back on iio_st_read_channel_raw
Support second value read back on iio_st_read_channel_raw. Bug 1287901 Change-Id: I2d5eb06ae3434fbca8a92591e8b498340371c771 Signed-off-by: Jinyoung Park <jinyoungp@nvidia.com> Reviewed-on: http://git-master/r/241373 Reviewed-by: Automatic_Commit_Validation_User GVS: Gerrit_Virtual_Submit Reviewed-by: Diwakar Tundlam <dtundlam@nvidia.com> Reviewed-by: Laxman Dewangan <ldewangan@nvidia.com>
Diffstat (limited to 'include/linux')
-rw-r--r--include/linux/iio/consumer.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/include/linux/iio/consumer.h b/include/linux/iio/consumer.h
index 1a15e560a5a1..8d3f45bd7802 100644
--- a/include/linux/iio/consumer.h
+++ b/include/linux/iio/consumer.h
@@ -62,13 +62,14 @@ void iio_st_channel_release_all(struct iio_channel *chan);
/**
* iio_st_read_channel_raw() - read from a given channel
* @channel: The channel being queried.
* @val: Value read back.
*
* Note raw reads from iio channels are in adc counts and hence
* scale will need to be applied if standard units required.
*/
int iio_st_read_channel_raw(struct iio_channel *chan,
- int *val);
+ int *val, int *val2);
/**
* iio_st_get_channel_type() - get the type of a channel
@@ -62,13 +62,14 @@ void iio_st_channel_release_all(struct iio_channel *chan);
* iio_st_read_channel_raw() - read from a given channel
* @channel: The channel being queried.
- * @val: Value read back.
+ * @val: First part of value read back.
+ * @val2: Second part of value read back.
*
* Note raw reads from iio channels are in adc counts and hence